==> cicdtest-1.71-py3-none-any.whl: ci_commands/pull.py <==
"""
    Title: pull.py
    Author: Kushagra A.
    Language: Python
    Date Created: 31-08-2021
    Date Modified: 11-09-2021
    Description:
        ###############################################################
        ## Create a webhook on a specific bitbucket repository   ## 
         ###############################################################
 """

import requests
import git
import os
import time
import datetime
from buildpan import setting, yaml_reader, deployer
import click


info = setting.info


# getting env variable
push_commit = info["PUSH_COMMIT_URL"]
fetch_log = info["FETCH_LOG_URL"]


@click.command()
def pull():
    '''
    For initiating the pull operation

    \f
    '''
    
    # pull

    all_repo_name = []

    with open("/home/kush/cron_test/buildpan_test/info.txt") as file:
        info = file.readlines()
        for data in info:
            d = eval(data)
            repo_name = d["repo_name"]
            repo_name = repo_name.lower()
            all_repo_name.append(repo_name)
 

    response = requests.get(push_commit)
    res=response.content
    res=str(res)
    index=res.index("'")
    index1=res.index("'",index+1)
    res=res[index+1:index1]
    res = res.lower()

    workflow = yaml_reader.yaml_reader.workflow
    jobs = yaml_reader.yaml_reader.jobs

    for repo in all_repo_name:

        if str(repo) == res:

            with open("/home/kush/cron_test/buildpan_test/info.txt") as file:
                info = file.readlines()
                for data in info:
                    d = eval(data)
                    repo_name = d["repo_name"]
                    repo_name = repo_name.lower()

                    if repo == repo_name:
                        path = d["path"]
                        print(path)
                        repo = git.Repo(path)
                        origin = repo.remote(name='origin')
                        res=origin.pull()
                        log = f"pull operation successful for {repo_name}"

                        start_time = datetime.datetime.now()
                        for job in workflow:
                            if job == "scripts":
                                success = deployer.script_runer(jobs[job], path)
       
                            elif job == "deploy":
                                if jobs[job]['appName'].lower() == 'Meanstack'.lower():
                                    success = deployer.mean_stack(path)
                                else:
                                    success = False
                                    print(f"{jobs[job]['appName']} is not Supported")
                                    break
                            else:
                                success = False

                #     curtime = datetime.datetime.now()          
                #     response2 = requests.post(fetch_log,data={'project_id':project_id,'repo_name':repo_name,'Time ':curtime,'user_name':username,'message':"pull success",'status':'pull operation performed'}) 

        else:
            log = "no files to pull"
            start_time = ""
                #     curtime = datetime.datetime.now()          
                #     response2 = requests.post(fetch_log,data={'project_id':project_id,'repo_name':repo_name,'Time ':curtime,'user_name':username,'message':"pull failed",'status':'pull operation performed'})
    
        with open("process.txt", "a") as file:
            file.write(log + "\n" + start_time + "\n")

==> cicdtest-1.86-py3-none-any.whl: ci_commands/pull.py <==
"""
    Title: pull.py
    Author: Kushagra A.
    Language: Python
    Date Created: 31-08-2021
    Date Modified: 11-09-2021
    Description:
        ###############################################################
        ## Check for pull operation on a repository   ## 
         ###############################################################
 """

from buildpan.previous_commit import prev_commit
import requests
import git
import os
import time
import datetime
from buildpan import setting, workflow, repo_pull
import click


info = setting.info


# getting env variable
push_commit = info["PUSH_COMMIT_URL"]


@click.command()
def pull():
    '''
    For initiating the pull operation

    \f
    '''
    
    # pull

    all_repo_name = []

    with open("/home/kush/cron_test/buildpan_test/info.txt") as file:
        info = file.readlines()
        for data in info:
            d = eval(data)
            repo_name = d["repo_name"]
            repo_name = repo_name.lower()
            all_repo_name.append(repo_name)
    
    params = {
        "repo_name": all_repo_name
    }
    

    response = requests.get(push_commit, params)
    res=response.content
    res=str(res)
    index=res.index("'")
    index1=res.index("'",index+1)
    res=res[index+1:index1]
    res = res.lower()

    for repo in all_repo_name:

        if str(repo) == res:

            with open("/home/kush/cron_test/buildpan_test/info.txt") as file:
                info = file.readlines()
                for data in info:
                    d = eval(data)
                    repo_name = d["repo_name"]
                    repo_name = repo_name.lower()

                    if repo == repo_name:
                        path = d["path"]
                        project_id = d["project_id"]
                        username = d["username"]

                        repo_pull.repo_pull(path, project_id, repo, username)
                        
                        log = f"pull operation successful for {repo_name}"

                        response = workflow.workflow(path)

                        if response == False:
                            prev_commit(path)
 

    # with open("process.txt", "a") as file:
    #     file.write(log + "\n")
